@@ -36,15 +36,42 @@ if($@ ne '')
   exit;
  }
  
-sub DB_OnExit
+$webtools::sys__subs__->{'DB_OnExit'} = \&flat_DB_OnExit;
+$webtools::sys__subs__->{'hideerror'} = \&flat_hideerror;
+$webtools::sys__subs__->{'sql_connect'} = \&flat_sql_connect;
+$webtools::sys__subs__->{'sql_connect2'} = \&flat_sql_connect2;
+$webtools::sys__subs__->{'test_connect'} = \&flat_test_connect;
+$webtools::sys__subs__->{'sql_disconnect'} = \&flat_sql_disconnect;
+$webtools::sys__subs__->{'sql_query'} = \&flat_sql_query;
+$webtools::sys__subs__->{'sql_fetchrow'} = \&flat_sql_fetchrow;
+$webtools::sys__subs__->{'sql_affected_rows'} = \&flat_sql_affected_rows;
+$webtools::sys__subs__->{'sql_inserted_id'} = \&flat_sql_inserted_id;
+$webtools::sys__subs__->{'sql_create_db'} = \&flat_sql_create_db;
+$webtools::sys__subs__->{'sql_drop_db'} = \&flat_sql_drop_db;
+$webtools::sys__subs__->{'sql_select_db'} = \&flat_sql_select_db;
+$webtools::sys__subs__->{'sql_num_fields'} = \&flat_sql_num_fields;
+$webtools::sys__subs__->{'sql_num_rows'} = \&flat_sql_num_rows;
+$webtools::sys__subs__->{'sql_data_seek'} = \&flat_sql_data_seek;
+$webtools::sys__subs__->{'sql_errmsg'} = \&flat_sql_errmsg;
+$webtools::sys__subs__->{'sql_errno'} = \&flat_sql_errno;
+$webtools::sys__subs__->{'sql_quote'} = \&flat_sql_quote;
+$webtools::sys__subs__->{'unsupported_types'} = \&flat_sql_unsupported_types;
+$webtools::sys__subs__->{'session_clear_expired'} = \&flat_session_clear_expired;
+$webtools::sys__subs__->{'session_expire_update'} = \&flat_session_expire_update;
+$webtools::sys__subs__->{'insert_sessions_row'} = \&flat_insert_sessions_row;
+$webtools::sys__subs__->{'DB_OnDestroy'} = \&flat_DB_OnDestroy;
+$webtools::sys__subs__->{'SignUpUser'} = \&flat_SignUpUser;
+$webtools::sys__subs__->{'SignInUser'} = \&flat_SignInUser;
+
+sub flat_DB_OnExit
    {
     my ($system_database_handle) = @_;
     if(!$system_database_handle->{AutoCommit}){$system_database_handle->commit();}
-    sql_disconnect($system_database_handle);
+    flat_sql_disconnect($system_database_handle);
     undef($system_database_handle);
     return(1);
    }
-sub hideerror 
+sub flat_hideerror 
      {
       eval
        {
@@ -67,16 +94,16 @@ sub hideerror
       print "<br><BR><font color='black'><h3>Please be nice and send e-mail to: $support_email </h3></font>";
       exit;
      }
-sub sql_connect   # No params needed!
+sub flat_sql_connect   # No params needed!
     {
      if($#_ == -1)
       {
-       if($system_database_handle ne undef) {sql_disconnect($system_database_handle);}
+       if($system_database_handle ne undef) {flat_sql_disconnect($system_database_handle);}
        my $oldslcthnd = select(STDOUT);
        if($db_path =~ m/^\.\./s) {$db_path = './';}
        $oldh = $SIG{'__WARN__'};
-       $SIG{'__WARN__'} = "hideerror";
-       my $OurSQL = DBI->connect("DBI:WTSprite:".$db_path."$sql_database_sessions",$sql_user,$sql_pass,{AutoCommit => 0, PrintError => 0}) or hideerror;
+       $SIG{'__WARN__'} = "flat_hideerror";
+       my $OurSQL = DBI->connect("DBI:WTSprite:".$db_path."$sql_database_sessions",$sql_user,$sql_pass,{AutoCommit => 0, PrintError => 0}) or flat_hideerror;
        $SIG{'__WARN__'} = $oldh;
        $system_database_handle = $OurSQL;   # That is current opened DB Handler!
        select($oldslcthnd);
@@ -91,16 +118,16 @@ sub sql_connect   # No params needed!
        $user = $user || $sql_user;
 
        $oldh = $SIG{'__WARN__'};
-       $SIG{'__WARN__'} = "hideerror";
+       $SIG{'__WARN__'} = "flat_hideerror";
        my $port = $port eq '' ? '' : ';port='.$port;
-       my $uOurSQL = DBI->connect("DBI:WTSprite:".$path."$database",$user,$pass,{AutoCommit => 0, PrintError => 0}) or hideerror;
+       my $uOurSQL = DBI->connect("DBI:WTSprite:".$path."$database",$user,$pass,{AutoCommit => 0, PrintError => 0}) or flat_hideerror;
        $SIG{'__WARN__'} = $oldh;
        $usystem_database_handle = $uOurSQL;   # That is current opened DB Handler!
        select($oldslcthnd);
        return($uOurSQL);
       }
     }
-sub test_connect
+sub flat_test_connect
    {
      my $oldslcthnd = select(STDOUT);
      if($db_path =~ m/^\.\./s) {$db_path = './';}
@@ -112,19 +139,19 @@ sub test_connect
      select($oldslcthnd);
      return($OurSQL);
    }
-sub sql_connect2
+sub flat_sql_connect2
     {
      my ($db) = @_;
      my $oldslcthnd = select(STDOUT);
      $oldh = $SIG{'__WARN__'};
-     $SIG{'__WARN__'} = "hideerror";
-     my $OurSQL = DBI->connect("DBI:WTSprite:".$db_path."$db",$sql_user,$sql_pass,{AutoCommit => 0, PrintError => 0}) or hideerror();
+     $SIG{'__WARN__'} = "flat_hideerror";
+     my $OurSQL = DBI->connect("DBI:WTSprite:".$db_path."$db",$sql_user,$sql_pass,{AutoCommit => 0, PrintError => 0}) or flat_hideerror();
      $SIG{'__WARN__'} = $oldh;
      $system_database_handle = $OurSQL;   # That is current opened DB Handler!
      select($oldslcthnd);
      return($OurSQL);     
     }
-sub sql_disconnect # Only db handler is required!
+sub flat_sql_disconnect # Only db handler is required!
    {
     my ($DBH) = @_;
     if(!$DBH->{AutoCommit}){$DBH->commit();}
@@ -132,7 +159,7 @@ sub sql_disconnect # Only db handler is required!
     undef($DBH);
     return (1);
    }
-sub sql_query   # ($query,$db_handler)
+sub flat_sql_query   # ($query,$db_handler)
     {
      my ($q,$DBH) = @_;
      $q =~ s/;$//s;
@@ -151,26 +178,26 @@ sub sql_query   # ($query,$db_handler)
       }
      else {flush_print();print "<BR><font color='red'><B>Error: Incorrect query!<B></font>";exit;return $DBH->errstr();}
     }
-sub sql_fetchrow    # ($result_handler)
+sub flat_sql_fetchrow    # ($result_handler)
     {
      my ($resdb) = @_;
      my $raRes = $resdb->fetchrow_arrayref();
      my @arr = @$raRes;
      return(@arr);
     }
-sub sql_affected_rows   # ($result_handler)
+sub flat_sql_affected_rows   # ($result_handler)
     {    
      my ($resdb) = @_;
      my $number = $resdb->rows;
      return($number);
     }
-sub sql_inserted_id   # ($result_handler)
+sub flat_sql_inserted_id   # ($result_handler)
     {    
      my ($resdb) = @_;
      my $number = undef;
      return($number);
     }    
-sub sql_create_db   # ($table_description,$db_handler) -> Not DB! This is TABLE!
+sub flat_sql_create_db   # ($table_description,$db_handler) -> Not DB! This is TABLE!
     {    
      my ($db,$DBH) = @_;
      $db =~ s/;$//s;
@@ -178,7 +205,7 @@ sub sql_create_db   # ($table_description,$db_handler) -> Not DB! This is TABLE!
      $DBH->commit();
      return($res);        # Just like Access Driver?
     }        
-sub sql_drop_db   # ($db_name,$db_handler) -> Not DB! This is TABLE!
+sub flat_sql_drop_db   # ($db_name,$db_handler) -> Not DB! This is TABLE!
     {    
      my ($db,$DBH) = @_;
      $db =~ s/;$//s;
@@ -186,11 +213,11 @@ sub sql_drop_db   # ($db_name,$db_handler) -> Not DB! This is TABLE!
      $DBH->commit();
      return($res);
     } 
-sub sql_select_db
+sub flat_sql_select_db
  {
     my($db, $self) = @_;
     if($db_path =~ m/^\.\./s) {$db_path = './';}
-    my $dbh = sql_connect('localhost',$db,$sql_user, $sql_pass, 0, $db_path);
+    my $dbh = flat_sql_connect('localhost',$db,$sql_user, $sql_pass, 0, $db_path);
     if (!$dbh) 
      {
       return(undef);
@@ -199,51 +226,45 @@ sub sql_select_db
      {
       if ($self) 
         {
-	 sql_disconnect($self);
+	 flat_sql_disconnect($self);
    	}
      }
     return($dbh);
  }
-sub sql_num_fields   # ($result_handler)
+sub flat_sql_num_fields   # ($result_handler)
     {    
      my ($resdb) = @_;
      my $number = $resdb->{NUM_OF_FIELDS};
      return($number);
     }
-sub sql_num_rows   # ($result_handler)
+sub flat_sql_num_rows   # ($result_handler)
     {    
      my ($resdb) = @_;
-     my $number = sql_affected_rows($resdb);
+     my $number = flat_sql_affected_rows($resdb);
      return($number);
     }
-sub sql_insert_id
-{
-  my ($res) = @_;
-  return(-1);
-}
-sub sql_errmsg
-{
-  my ($dbh) = @_;
-  return($DBI::errstr);
-}
-
-sub sql_errno
-{
-  my ($dbh) = @_;
-  return($DBI::err);
-}
-sub sql_data_seek
+sub flat_sql_data_seek
 {
  my ($row,$res) = @_;
  return(-1);
 }
-sub sql_quote
+sub flat_sql_errmsg
+{
+  my ($dbh) = @_;
+  return($DBI::errstr);
+}
+sub flat_sql_errno
+{
+  my ($dbh) = @_;
+  return($DBI::err);
+}
+sub flat_sql_quote
 {
  my ($unquoted_string,$dbh) = @_;
  my $str = $dbh->quote($unquoted_string);
  return($str);
 }
-sub sql_unsupported_types
+sub flat_sql_unsupported_types
 {
  my ($q,$DBH) = @_;
  return($q);
@@ -251,7 +272,7 @@ sub sql_unsupported_types
 #####################################################################
 # Session Support Functions
 #####################################################################
-sub session_clear_expired
+sub flat_session_clear_expired
 {
  my ($dbh) = @_;
  my $i_id;
@@ -259,7 +280,7 @@ sub session_clear_expired
  my @my_array;
  if($sess_force_flat eq 'off') ###DB###
  {
-  my $er = sql_query("delete from $sql_sessions_table where EXPIRE < $ctime;",$dbh);
+  my $er = flat_sql_query("delete from $sql_sessions_table where EXPIRE < $ctime;",$dbh);
   if ($er eq undef) { return(0); }
  }
  else
@@ -269,7 +290,7 @@ sub session_clear_expired
  }
  return(1);
 }
-sub session_expire_update
+sub flat_session_expire_update
 {
  my ($dbh) = @_;
  my %calmin  = ('second',1,'minute',60,'hour',3600,'day',86400,'month',2678400,'year',31536000);
@@ -285,7 +306,7 @@ sub session_expire_update
     {
      $r_q = " and IP = \'$ip\'";    # Restrict session on IP!
     }
-  my $r = sql_query("update $sql_sessions_table set EXPIRE = $inter where S_ID = \'$sys_local_sess_id\'".$r_q,$dbh);
+  my $r = flat_sql_query("update $sql_sessions_table set EXPIRE = $inter where S_ID = \'$sys_local_sess_id\'".$r_q,$dbh);
   if ($r eq undef) { return(0);}
  }
  else
@@ -295,7 +316,7 @@ sub session_expire_update
  }
  return (1);
 }
-sub insert_sessions_row   # ($session_id,$db_handler)
+sub flat_insert_sessions_row   # ($session_id,$db_handler)
 {
   my ($dbh) = @_;
   my %calmin  = ('second',1,'minute',60,'hour',3600,'day',86400,'month',2678400,'year',31536000);
@@ -323,14 +344,14 @@ sub insert_sessions_row   # ($session_id,$db_handler)
   }
   return(0);
 }
-sub DB_OnDestroy
+sub flat_DB_OnDestroy
  {
    return(1);        # Something like Commit!
  }
 #####################################################################
 # USER DEFINED FUNCTIONS
 #####################################################################
-sub SignUpUser
+sub flat_SignUpUser
 {
  my ($user,$pass,$data,$active,$fname,$lname,$email,$dbh) = @_;
  my $ut = "SELECT USER FROM $sql_user_table WHERE USER=?";
@@ -340,7 +361,7 @@ sub SignUpUser
  $rut->execute($user);
 
  my @arr = ();
- eval {@arr = sql_fetchrow($rut);};
+ eval {@arr = flat_sql_fetchrow($rut);};
  if ($arr[0] ne '') {return(0);}
  else
   {
@@ -354,18 +375,18 @@ sub SignUpUser
   } 
  return(0); 
 }
-sub SignInUser
+sub flat_SignInUser
 {
  my ($user,$pass,$dbh) = @_;
- $user = sql_quote($user,$dbh);
- $pass = sql_quote($pass,$dbh);
+ $user = flat_sql_quote($user,$dbh);
+ $pass = flat_sql_quote($pass,$dbh);
  my $q = "SELECT ID,DATA FROM $sql_user_table WHERE USER=$user and PASSWORD=$pass and ACTIVE='Y';";
- my $res = sql_query($q,$dbh);
+ my $res = flat_sql_query($q,$dbh);
  if ($res eq undef)
    {
     return((undef,undef));
    }
- my ($ID,$DATA) = sql_fetchrow($res);
+ my ($ID,$DATA) = flat_sql_fetchrow($res);
  if ($ID eq '') {return((undef,undef)); }
  return($ID,$DATA);
 }
